@@ -385,7 +385,7 @@ class App(object):
         # Makes generic meta file if no specified meta file is
         # passed in
         if meta_file is None:
-            meta_file = configuration_file.ConfigurationFile()
+            meta_file = configuration_file.ConfigurationFile(name)
 
         with open(app_filepath, "rb") as file:
             meta_file = configuration_parser.parse(
