@@ -229,13 +229,15 @@ def get_imported_matches(file):
                 matches.append(match)
     return matches
 
-
-def parse_static_js_match(match):
-    """Utility function that parses a static/js file match into a require-style import.
+def parse_static_match(match, prefix):
+    """Utility function that parses a static file match into a require-style import.
 
     @param
     file <String>: Static file path
 
+    @param
+    prefix <String>: A prefix to the variable file path
+
     Returns
     matches <String>: Require-style import path
 
@@ -247,7 +249,7 @@ def parse_static_js_match(match):
 
     'foo/bar'
     """
-    split_match = match.split("/static/js/")
+    split_match = match.split("/static/{}/".format(prefix))
     match = split_match[1] if len(split_match) > 1 else None
     if match and "." in match:
         return ".".join(match.split(".")[:-1])
@@ -267,19 +269,22 @@ def get_static_matches(file):
 
     make_url('/static/js/foo/bar.js')
     make_url('/static/js/views/Base.js')
+    <script src="/static/build/simplexml/index.js"></script>
 
     returns
 
-    ['foo/bar', 'views/Base']
+    ['foo/bar', 'views/Base', 'simplexml/index']
     """
     matches = []
-    pattern = re.compile(r"(make_url)\([^)]+\)")
+    pattern = re.compile(r"(\/static\/)[^\"|\']+")
     for matched_object in pattern.finditer(file):
-        imported_matches = re.finditer(r"['\"]([^'\"]*)['\"]", matched_object.group())
-        for imported in imported_matches:
-            match = parse_static_js_match(imported.group(1))
-            if match and match not in matches:
-                matches.append(match)
+        candiate = matched_object.group()
+        match = parse_static_match(candiate, 'js')
+        if match and match not in matches:
+            matches.append(match)
+        match = parse_static_match(candiate, 'build')
+        if match and match not in matches:
+            matches.append(match)
     return matches
 
 
