@@ -93,8 +93,7 @@ def check_that_setup_has_not_been_performed(app, reporter):
     "splunk_appinspect",
     "cloud", "self-service",
     "private_app",
-    "private_victoria",
-    "private_classic"
+    "private_victoria"
 )
 @splunk_appinspect.cert_version(min="2.0.1")
 def check_for_valid_package_id(app, reporter):
