@@ -95,7 +95,7 @@ def _traverse_all_imported_python_files(file_full_path):
 
 
 @splunk_appinspect.tags(
-    "splunk_appinspect", "cloud", "self-service"
+    "splunk_appinspect", "cloud", "private_app", "private_victoria"
 )
 def check_idx_binary_compatibility(app, reporter):
     """Checks that binaries that are distributed to the IDX tier of a distributed Splunk platform deployment are
@@ -197,7 +197,7 @@ def check_idx_binary_compatibility(app, reporter):
                 reporter.warn(binary_status["error"], inspect_file_name)
             elif binary_status["binary"] and not binary_status["arm"]:
                 # Change from warning to fail 3 months after deploying
-                reporter.warn(
+                reporter.fail(
                     f"The following file is incompatible with the ARM aarch64 architecture. "
                     f"Compatibility with this architecture is required for code that will be executed "
                     f"on the Indexer tier of the Splunk Cloud Platform.",
