@@ -64,7 +64,7 @@ def check_validate_default_indexes_not_modified(app, reporter):
                 )
                 reporter.fail(reporter_output, file_path, section.lineno)
     else:
-        reporter_output = "No `default/indexes.conf`file exists."
+        reporter_output = "No `default/indexes.conf` file exists."
         reporter.not_applicable(reporter_output)
 
 
@@ -223,3 +223,26 @@ def check_coldToFrozenScript_has_valid_python_version_property(
     else:
         reporter_output = "indexes.conf does not exist."
         reporter.not_applicable(reporter_output)
+
+
+@splunk_appinspect.cert_version(min="2.23.0")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
+def check_lower_cased_index_names(app, reporter):
+    """Check that all index names contain lowercase characters. If index names have any upper
+    case characters any attempts to edit the index in the UI will cause a duplicate
+    index stanza creation which will cause many errors in Splunk."""
+
+    if app.file_exists("default", "indexes.conf"):
+        file_path = os.path.join("default", "indexes.conf")
+        indexes_config = app.get_config("indexes.conf")
+        for section in indexes_config.sections():
+            if not section.name.islower():
+                reporter_output = (
+                    f"The index [{section.name}] contains uppercase characters which is "
+                    "not allowed. Please ensure index names contain only lowercase characters. "
+                    f"File: {file_path}, Line: {section.lineno}."
+                )
+                reporter.fail(reporter_output, file_path, section.lineno)
+    else:
+        reporter_output = "No `default/indexes.conf` file exists."
+        reporter.not_applicable(reporter_output)
