@@ -73,7 +73,11 @@ def check_hotlinking_splunk_web_libraries(app, reporter):
         app.get_filepaths_of_files(basedir="appserver/templates", types=[".html"])
     )
     unpacked_html_template_files = util.unpack_absolute_path(html_template_files)
-    unpacked_html_files = unpacked_html_dashboard_files + unpacked_html_template_files
+    html_static_template_files = list(
+        app.get_filepaths_of_files(basedir="appserver/static/template", types=[".html"])
+    )
+    unpacked_html_static_template_files = util.unpack_absolute_path(html_static_template_files)
+    unpacked_html_files = unpacked_html_dashboard_files + unpacked_html_template_files + unpacked_html_static_template_files
 
     # Get list of files from search head (disallowed_imports.json)
     disallowed_json_path = os.path.abspath(
