@@ -8,6 +8,8 @@ These checks validate that a Splunk app has been correctly packaged, and can be
 import logging
 import os
 import stat
+import json
+from packaging import version
 from functools import wraps
 
 import splunk_appinspect
@@ -204,7 +206,7 @@ def check_that_splunk_app_package_does_not_contain_files_outside_of_app(app, rep
 @splunk_appinspect.cert_version(min="1.5.3")
 @app_package_extractable
 def check_that_splunk_app_package_with_static_dependencies_has_exactly_one_app_folder(
-    app, reporter
+        app, reporter
 ):
     """Check that the Splunk App package with a .dependencies directory also
     contains exactly one valid app folder.
@@ -234,10 +236,10 @@ def check_that_splunk_app_package_with_static_dependencies_has_exactly_one_app_f
         app.package.working_app_path, app.package.working_artifact
     )
     if (
-        len(contents) != 2
-        or not all_contents_are_folders
-        or relative_dependencies_path not in contents
-        or relative_working_app_path not in contents
+            len(contents) != 2
+            or not all_contents_are_folders
+            or relative_dependencies_path not in contents
+            or relative_working_app_path not in contents
     ):
         reporter_output = (
             f"Only a single app folder and a single {app.dependencies_directory_path} "
@@ -260,7 +262,7 @@ def check_that_splunk_app_package_with_static_dependencies_has_exactly_one_app_f
 @splunk_appinspect.cert_version(min="1.5.3")
 @app_package_extractable
 def check_that_splunk_app_package_with_static_dependencies_has_app_manifest(
-    app, reporter
+        app, reporter
 ):
     """Check that the Splunk App package with a .dependencies directory also
     contains an app folder with an app.manifest.
@@ -361,7 +363,7 @@ def check_that_splunk_app_package_has_valid_static_dependencies(app, reporter):
 @splunk_appinspect.cert_version(min="1.5.0")
 @app_package_extractable
 def check_that_extracted_splunk_app_does_not_contain_prohibited_directories_or_files(
-    app, reporter
+        app, reporter
 ):
     """Check that the extracted Splunk App does not contain any directories or
     files that start with a `.`, or directories that start with `__MACOSX`.
@@ -394,13 +396,7 @@ def check_that_extracted_splunk_app_contains_default_app_conf_file(app, reporter
     """Check that the extracted Splunk App contains a `default/app.conf`
     file.
     """
-    if not app.package.does_working_artifact_contain_default_app_conf():
-        reporter_output = (
-            "Splunk App packages must contain a"
-            " `default/app.conf file`."
-            f" No `default/app.conf` was found in `{app.package.origin_artifact_name}`."
-        )
-        reporter.fail(reporter_output)
+    _is_check_app_config_file(app, reporter, "fail")
 
 
 @splunk_appinspect.tags(
@@ -410,56 +406,164 @@ def check_that_extracted_splunk_app_contains_default_app_conf_file(app, reporter
     "packaging_standards",
     "self-service",
     "private_app",
-    "private_victoria",
-    "private_classic"
+    "private_victoria"
 )
 @splunk_appinspect.cert_version(min="1.5.0")
-def check_that_extracted_splunk_app_contains_default_app_conf_file_with_valid_version_number(
-    app, reporter
-):
+def check_valid_version_number(app, reporter):
     """Check that the extracted Splunk App contains a `default/app.conf` file
     that contains an `[id]` or `[launcher]` stanza with a `version` property that
     is formatted as `Major.Minor.Revision`.
     """
 
-    filename = os.path.join("default", "app.conf")
-    if not app.file_exists(filename):
+    app_config_skip_check = _is_check_app_config_file(app, reporter, "skip")
+
+    if not app_config_skip_check:
+        filename = os.path.join("default", "app.conf")
+        config = app.get_config(os.path.basename(filename))
+        matcher = AppVersionNumberMatcher()
+        id_version = launcher_version = None
+
+        try:
+            config.has_option("id", "version")
+            id_version = config.get("id", "version")
+            if not matcher.match(id_version):
+                lineno_id_version = config.get_section("id").get_option("version").lineno
+                reporter_output = (
+                    "`Major.Minor.Revision` version numbering is required "
+                    f"in `[id]` section of app.conf. File: {filename}, [id] Line: {lineno_id_version}."
+                )
+                reporter.fail(reporter_output, filename, lineno_id_version)
+
+        except splunk_appinspect.configuration_file.NoOptionError:
+            lineno_id = config.get_section("id").lineno
+            reporter_output = (
+                "No `version` specified in `[id]` "
+                f"section of app.conf. File: {filename}, [id] Line: {lineno_id}."
+            )
+            reporter.fail(reporter_output, filename, lineno_id)
+
+        except splunk_appinspect.configuration_file.NoSectionError:
+            reporter_output = (
+                "No `[id]` section found in app.conf file."
+            )
+            reporter.fail(reporter_output, filename)
+
+        try:
+            config.has_option("launcher", "version")
+            launcher_version = config.get("launcher", "version")
+            if not matcher.match(launcher_version):
+                lineno_launcher_version = config.get_section("launcher").get_option("version").lineno
+                reporter_output = (
+                    "`Major.Minor.Revision` version numbering is required "
+                    "in `[launcher]` section of app.conf. "
+                    f"File: {filename}, launcher version lineno: {lineno_launcher_version}"
+                )
+                reporter.fail(reporter_output, filename, lineno_launcher_version)
+
+        except splunk_appinspect.configuration_file.NoOptionError:
+            lineno_launcher = config.get_section("launcher").lineno
+            reporter_output = (
+                "No `version` specified in `[launcher]` "
+                f"section of app.conf. File: {filename}, [launcher] line: {lineno_launcher}."
+            )
+            reporter.fail(reporter_output, filename, lineno_launcher)
+
+        except splunk_appinspect.configuration_file.NoSectionError:
+            reporter_output = (
+                "No `[launcher]` section found in app.conf file."
+            )
+            reporter.fail(reporter_output, filename)
+
+        if id_version is not None and launcher_version is not None:
+            if version.parse(id_version) != version.parse(launcher_version):
+                lineno_id = config.get_section("id").get_option("version").lineno
+                lineno_launcher = config.get_section("launcher").get_option("version").lineno
+                reporter_output = (
+                    "The `id.version` and `launcher.version` is not equivalent."
+                    f"Please make sure that `version` of both `[id]` and `[launcher]` section is matching"
+                    f"File: {filename}, id.version line: {lineno_id}, launcher.version line: {lineno_launcher}."
+                )
+                reporter.fail(reporter_output, filename, lineno_id, lineno_launcher)
+
+    if not app.package.does_working_artifact_contain_app_manifest():
         reporter_output = (
-            "Splunk App packages must contain a"
-            " `default/app.conf file`."
-            " No `default/app.conf` was found "
-            f" in `{app.package.origin_artifact_name}`."
+            "Splunk App packages doesn't contain"
+            " `default/app.manifest file`."
+            " No `default/app.manifest` was found."
         )
-        reporter.fail(reporter_output)
+        reporter.skip(reporter_output)
         return
 
-    config = app.get_config(os.path.basename(filename))
-    matcher = AppVersionNumberMatcher()
+    manifest_filename = os.path.join("app.manifest")
+    try:
+        filepath = open(os.path.join(app.app_dir, "app.manifest"), "r")
+        manifest_json = json.loads(filepath.read())
+        manifest_version = manifest_json.get("info").get("id").get("version")
+        if not matcher.match(manifest_version):
+            reporter_output = (
+                "`Major.Minor.Revision` version numbering is required "
+                "in `[info][id]` section of app.manifest. "
+                f"File: {manifest_filename}."
+            )
+            reporter.fail(reporter_output, manifest_filename)
 
-    # the matcher matches both x.x and x.x.x formats,
-    # so we expect 2 matches
+    except ValueError:
+        reporter_output = (
+            "The app.manifest file is not in correct format. "
+            f"File: {manifest_filename}."
+        )
+        reporter.fail(reporter_output, manifest_filename)
+        return
 
-    num_matches = 0
+    except KeyError:
+        reporter_output = (
+            "No `version` specified under `[info][id]` "
+            f"section of app.manifest. File: {manifest_filename}."
+        )
+        reporter.fail(reporter_output, manifest_filename)
+        return
+    except:
+        reporter_output = (
+            f"Some other exception came. File: {manifest_filename}"
+        )
+        reporter.fail(reporter_output, manifest_filename)
+        return
 
-    if config.has_option("id", "version"):
-        version = config.get("id", "version")
-        num_matches = max(num_matches, len(matcher.match(version)))
+    try:
+        if version.parse(manifest_version) != version.parse(id_version) and version.parse(
+                manifest_version) != version.parse(launcher_version):
+            reporter_output = (
+                "The `info.id.version` and `id.version` and `launcher.version` is not equivalent."
+                "Please make sure that version of info.id, id and launcher tag is matching"
+                f"File: {manifest_filename} or {filename}"
+            )
+            reporter.fail(reporter_output, manifest_filename)
+    except:
+        reporter_output = (
+            f"No `version` found in app.conf or app.manifest file and hence won't be able to check the equivalency. "
+            f"File; {manifest_filename} or {filename}"
+        )
+        reporter.fail(reporter_output, manifest_filename)
 
-    if config.has_option("launcher", "version"):
-        version = config.get("launcher", "version")
-        num_matches = max(num_matches, len(matcher.match(version)))
 
-    reporter_output = (
-        "`Major.Minor.Revision` version is required "
-        "in `[id]` or `[launcher]` section of app.conf. "
-    )
+def _is_check_app_config_file(app, reporter, status='not_applicable'):
+    if not app.package.does_working_artifact_contain_default_app_conf():
+        reporter_output = (
+            "Splunk App packages should contain a"
+            " `default/app.conf file`."
+            f" No `default/app.conf` was found in `{app.package.origin_artifact_name}`."
+        )
 
-    if not num_matches:
-        reporter.fail(reporter_output, file_name=filename)
+        if status == "fail":
+            reporter.fail(reporter_output)
+        elif status == "warn":
+            reporter.warn(reporter_output)
+        elif status == "skip":
+            reporter.skip(reporter_output)
+        else:
+            reporter.not_applicable(reporter_output)
 
-    if num_matches == 1:
-        # there's only an x.x version, so give a warning
-        reporter.warn(reporter_output, file_name=filename)
+        return True
 
 
 @splunk_appinspect.tags(
@@ -501,7 +605,7 @@ def check_that_extracted_splunk_app_does_not_contain_invalid_directories(app, re
 @splunk_appinspect.cert_version(min="1.5.0")
 @app_package_extractable
 def check_that_extracted_splunk_app_does_not_contain_files_with_invalid_permissions(
-    app, reporter
+        app, reporter
 ):
     """Check that the extracted Splunk App does not contain any files
     with incorrect permissions. Files must have the owner's
