@@ -441,7 +441,7 @@ def check_symlink_outside_app(app, reporter):
                     reporter.fail(reporter_output, app_file_path)
 
 
-@splunk_appinspect.tags("cloud", "privaite_app", "splunk_9_0", "future", "private_victoria", "private_classic", "pura")
+@splunk_appinspect.tags("cloud", "private_app", "splunk_9_0", "future", "private_victoria", "private_classic", "pura")
 def check_for_supported_tls(app, reporter):
     """Check that all outgoing connections use TLS in accordance to Splunk Cloud Platform policy."""
     client = app.python_analyzer_client
