@@ -15,7 +15,7 @@ report_display_order = 2
 logger = logging.getLogger(__name__)
 
 
-@splunk_appinspect.tags("cloud", "private_app")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.6.1")
 def check_server_conf_only_contains_custom_conf_sync_stanzas_or_diag_stanza(
     app, reporter
