@@ -2,8 +2,12 @@
 Execute xml ElementTree commands
 """
 
-from splunk_appinspect.python_modules_metadata.metadata_common.metadata_consts import TagConsts
-from splunk_appinspect.python_modules_metadata.metadata_common.metadata_decorator import tags
+from splunk_appinspect.python_modules_metadata.metadata_common.metadata_consts import (
+    TagConsts,
+)
+from splunk_appinspect.python_modules_metadata.metadata_common.metadata_decorator import (
+    tags,
+)
 
 
 @tags(TagConsts.FILE_READ_AND_WRITE)
@@ -13,6 +17,7 @@ def parse():
     """
     pass
 
+
 @tags(TagConsts.FILE_READ_AND_WRITE)
 def iterparse():
     """
@@ -24,8 +29,8 @@ def iterparse():
 @tags(TagConsts.FILE_READ_AND_WRITE)
 def dump():
     """
-     Writes an element tree or element structure to sys.stdout.  This
-     function should be used for debugging only.
+    Writes an element tree or element structure to sys.stdout.  This
+    function should be used for debugging only.
     """
     pass
 
@@ -34,6 +39,7 @@ class ElementTree:
     """
     ElementTree class
     """
+
     @tags(TagConsts.FILE_READ_AND_WRITE)
     def write(self):
         """
@@ -47,6 +53,3 @@ class ElementTree:
         Loads an external XML document into this element tree.
         """
         pass
-
-
-
