@@ -137,6 +137,34 @@ class JSInsecureHttpRequestMatcher(RegexMatcher):
         )
 
 
+class JSSplunkJSMatcher(RegexMatcher):
+    def __init__(self):
+
+        possible_splunkjs_regex_patterns = [RegexBundle(r"splunkjs\/mvc")]
+        super(JSSplunkJSMatcher, self).__init__(possible_splunkjs_regex_patterns)
+
+
+class JSSplunkReactUIMatcher(RegexMatcher):
+    def __init__(self):
+
+        possible_splunkreactui_regex_patterns = [RegexBundle(r"@splunk\/react-ui")]
+        super(JSSplunkReactUIMatcher, self).__init__(possible_splunkreactui_regex_patterns)
+
+
+class JSSplunkDashboardCoreMatcher(RegexMatcher):
+    def __init__(self):
+
+        possible_splunkdashboardcore_regex_patterns = [RegexBundle(r"@splunk\/dashboard-core")]
+        super(JSSplunkDashboardCoreMatcher, self).__init__(possible_splunkdashboardcore_regex_patterns)
+
+
+class JSSplunkVisualizationsMatcher(RegexMatcher):
+    def __init__(self):
+
+        possible_splunkvisualizations_regex_patterns = [RegexBundle(r"@splunk\/visualizations")]
+        super(JSSplunkVisualizationsMatcher, self).__init__(possible_splunkvisualizations_regex_patterns)
+
+
 class JSIFrameMatcher(RegexMatcher):
     def __init__(self):
 
