@@ -5,24 +5,22 @@
 This module contains functions to accumulate and run checks under configurations
 as needed.
 """
-
-# Python Standard Libraries
+import concurrent.futures
 import logging
 
-# Third-Party Libraries
-import concurrent.futures
 from futures_then import ThenableFuture
 
-# Custom Libraries
 import splunk_appinspect
 from splunk_appinspect.checks import Group
-from splunk_appinspect.validation_report import ValidationReport
-from splunk_appinspect.validation_report import ApplicationValidationReport
 from splunk_appinspect.python_analyzer.trustedlibs.trusted_libs_manager import (
     TrustedLibsManager,
 )
-from . import infra
+from splunk_appinspect.validation_report import (
+    ApplicationValidationReport,
+    ValidationReport,
+)
 
+from . import infra
 
 logger = logging.getLogger(__name__)
 PACKAGING_STANDARDS_TAG = "packaging_standards"
@@ -114,9 +112,9 @@ class Validator(object):
             self.app_class = splunk_appinspect.App
         else:
             logger_output = (
-                "The custom app_class '{}' was provided to the"
+                f"The custom app_class '{app_class}' was provided to the"
                 " validate_packages function."
-            ).format(app_class)
+            )
             logger.info(logger_output)
 
         self.appinspect_version = splunk_appinspect.version.__version__
@@ -310,7 +308,9 @@ class Validator(object):
 
         while reporter.state() == "error" and retries < MAX_CHECK_RETRIES:
             retries += 1
-            logger.info(f"Retrying check because it produced an error, check_name={check.name}")
+            logger.info(
+                f"Retrying check because it produced an error, check_name={check.name}"
+            )
             self.__emit_event("retry_check", self.listeners, check, reporter)
             reporter = check.run(app, context)
 
